@@ -272,6 +272,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_apigatewayv2
@@ -389,6 +391,10 @@ class HttpJwtAuthorizer(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(HttpJwtAuthorizer.__init__)
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument jwt_issuer", value=jwt_issuer, expected_type=type_hints["jwt_issuer"])
         props = HttpJwtAuthorizerProps(
             jwt_audience=jwt_audience,
             authorizer_name=authorizer_name,
@@ -463,6 +469,11 @@ class HttpJwtAuthorizerProps:
                 authorizer=authorizer
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(HttpJwtAuthorizerProps.__init__)
+            check_type(argname="argument jwt_audience", value=jwt_audience, expected_type=type_hints["jwt_audience"])
+            check_type(argname="argument authorizer_name", value=authorizer_name, expected_type=type_hints["authorizer_name"])
+            check_type(argname="argument identity_source", value=identity_source, expected_type=type_hints["identity_source"])
         self._values: typing.Dict[str, typing.Any] = {
             "jwt_audience": jwt_audience,
         }
@@ -570,6 +581,10 @@ class HttpLambdaAuthorizer(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(HttpLambdaAuthorizer.__init__)
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument handler", value=handler, expected_type=type_hints["handler"])
         props = HttpLambdaAuthorizerProps(
             authorizer_name=authorizer_name,
             identity_source=identity_source,
@@ -650,6 +665,12 @@ class HttpLambdaAuthorizerProps:
                 authorizer=authorizer
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(HttpLambdaAuthorizerProps.__init__)
+            check_type(argname="argument authorizer_name", value=authorizer_name, expected_type=type_hints["authorizer_name"])
+            check_type(argname="argument identity_source", value=identity_source, expected_type=type_hints["identity_source"])
+            check_type(argname="argument response_types", value=response_types, expected_type=type_hints["response_types"])
+            check_type(argname="argument results_cache_ttl", value=results_cache_ttl, expected_type=type_hints["results_cache_ttl"])
         self._values: typing.Dict[str, typing.Any] = {}
         if authorizer_name is not None:
             self._values["authorizer_name"] = authorizer_name
@@ -793,6 +814,10 @@ class HttpUserPoolAuthorizer(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(HttpUserPoolAuthorizer.__init__)
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument pool", value=pool, expected_type=type_hints["pool"])
         props = HttpUserPoolAuthorizerProps(
             authorizer_name=authorizer_name,
             identity_source=identity_source,
@@ -868,6 +893,12 @@ class HttpUserPoolAuthorizerProps:
                 user_pool_region="userPoolRegion"
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(HttpUserPoolAuthorizerProps.__init__)
+            check_type(argname="argument authorizer_name", value=authorizer_name, expected_type=type_hints["authorizer_name"])
+            check_type(argname="argument identity_source", value=identity_source, expected_type=type_hints["identity_source"])
+            check_type(argname="argument user_pool_clients", value=user_pool_clients, expected_type=type_hints["user_pool_clients"])
+            check_type(argname="argument user_pool_region", value=user_pool_region, expected_type=type_hints["user_pool_region"])
         self._values: typing.Dict[str, typing.Any] = {}
         if authorizer_name is not None:
             self._values["authorizer_name"] = authorizer_name
@@ -986,6 +1017,10 @@ class WebSocketLambdaAuthorizer(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(WebSocketLambdaAuthorizer.__init__)
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument handler", value=handler, expected_type=type_hints["handler"])
         props = WebSocketLambdaAuthorizerProps(
             authorizer_name=authorizer_name, identity_source=identity_source
         )
@@ -1047,6 +1082,10 @@ class WebSocketLambdaAuthorizerProps:
                 identity_source=["identitySource"]
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(WebSocketLambdaAuthorizerProps.__init__)
+            check_type(argname="argument authorizer_name", value=authorizer_name, expected_type=type_hints["authorizer_name"])
+            check_type(argname="argument identity_source", value=identity_source, expected_type=type_hints["identity_source"])
         self._values: typing.Dict[str, typing.Any] = {}
         if authorizer_name is not None:
             self._values["authorizer_name"] = authorizer_name
